# metadata

This repository contains state metadata that powers Open States.

[![CircleCI](https://circleci.com/gh/openstates/metadata.svg?style=svg)](https://circleci.com/gh/openstates/metadata)

## Links

* [Open States Discourse](https://discourse.openstates.org)
* [Code of Conduct](https://docs.openstates.org/en/latest/contributing/code-of-conduct.html)

## Changelog

Releases use YYYY.MM.patch versioning.

### 2020.04.4

* add lookup_district helper function

### 2020.04.3

* add executive_organization_id and executive_name to State

### 2020.04.2 - Apr 8 2020

* fix unicameral legislature ids

### 2020.04.1 - Apr 8 2020

* add State.legislature_organization_id

### 2020.02.2 - Feb 6 2020

* lower minimum Python version to 3.6

### 2020.02.1 - Feb 5 2020

* remove unnecessary dependencies
* add lookup by name option

### 2020.01.31 - Jan 31 2020

* added organization_ids to chambers
* added legacy_districts for states with district changes since 2010

### 2020.01.16 - Jan 15 2020

* Added helper methods.

### 2020.01.15 - Jan 15 2020

* First release, basic functionality.
